@@ -490,7 +490,7 @@ on_pgp_owner_photo_drag_received (GtkWidget *widget, GdkDragContext *context, gi
      * and there has to be a better way to get rid of the trailing \r\n appended
      * to the end of the path after the call to g_filename_from_uri
      */
-    if((sel_data != NULL) && (sel_data->length >= 0)) {
+    if((sel_data != NULL) && (gtk_selection_data_get_length (sel_data) >= 0)) {
         g_return_if_fail (target_type == TARGET_URI);
         
         uri_list = gtk_selection_data_get_uris (sel_data);
@@ -996,16 +996,18 @@ static void
 export_complete (GFile *file, GAsyncResult *result, gchar *contents)
 {
 	GError *err = NULL;
-	gchar *uri;
+	gchar *uri, *unesc_uri;
 	
 	g_free (contents);
 
 	if (!g_file_replace_contents_finish (file, result, NULL, &err)) {
 		uri = g_file_get_uri (file);
-	        seahorse_util_handle_error (err, _("Couldn't export key to \"%s\""),
-	                                    seahorse_util_uri_get_last (uri));
-	        g_clear_error (&err);
-	        g_free (uri);
+		unesc_uri = g_uri_unescape_string (seahorse_util_uri_get_last (uri), NULL);
+        seahorse_util_handle_error (err, _("Couldn't export key to \"%s\""),
+                                    unesc_uri);
+        g_clear_error (&err);
+        g_free (uri);
+        g_free (unesc_uri);
 	}
 }
 
@@ -1745,8 +1747,8 @@ do_trust (SeahorseWidget *swidget)
 			
 			gtk_tree_view_set_model (GTK_TREE_VIEW (widget), GTK_TREE_MODEL(filter));
 			widget = GTK_WIDGET (seahorse_widget_get_widget (swidget, "signatures-toggle"));
+			g_signal_connect (widget, "toggled", G_CALLBACK (on_pgp_trusted_toggled), filter);
 			gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON (widget), TRUE);
-			on_pgp_trusted_toggled (GTK_TOGGLE_BUTTON (widget), filter);
 		}
 	}
 
